@@ -1,6 +1,6 @@
 import sys
 
 if sys.version_info >= (3, 7):
-    from contextlib import asynccontextmanager as asynccontextmanager
+    from contextlib import asynccontextmanager as asynccontextmanager  # noqa
 else:
     from contextlib2 import asynccontextmanager as asynccontextmanager  # noqa
